Learn R Programming

PMwR (version 0.10-1)

PMwR-internal: Internal Functions

Description

Several internal functions, not exported from the PMwR name space.

Usage

.timestamp(x)
.timestamp(x) <- value

.may_be_Date(x, …)

Arguments

Details

.timestamp extracts or replaces an objects timestamp.

.may_be_Date checks whether a vector could be coerced to class Date, in which case it evaluates to (a single) TRUE; otherwise it returns FALSE.

References

PMwR manual