powered by
Several internal functions, not exported from the PMwR name space.
.timestamp(x) .timestamp(x) <- value.may_be_Date(x, …)
.may_be_Date(x, …)
.timestamp extracts or replaces an objects timestamp.
.timestamp
.may_be_Date checks whether a vector could be coerced to class Date, in which case it evaluates to (a single) TRUE; otherwise it returns FALSE.
.may_be_Date
Date
TRUE
FALSE
PMwR manual